Module output

Module output 

Generate output structures for lock traces and static data like lock modes. This module is used by the binary to generate output in various formats is currently the best documentation of output format, and can be considered a public api for the library.

Re-exports

pub use output_format::Column;
pub use output_format::Constraint;
pub use output_format::DbObject;
pub use output_format::FullSqlStatementLockTrace;
pub use output_format::FullTraceData;
pub use output_format::GenericHint;
pub use output_format::Hint;
pub use output_format::LintReport;
pub use output_format::LintedStatement;
pub use output_format::ModifiedColumn;
pub use output_format::ModifiedConstraint;
pub use output_format::TracedLock;

Modules

output_format
Output types for the lock tracing library, exportable to JSON and public API.
templates
Markdown rendering utilities for lock traces and lints.

Structs

DetailedLockMode
LockModesWrapper
Settings
TerseLockMode

Functions

full_trace_data