Struct eugene::pgpass::PgPassFile
source · pub struct PgPassFile { /* private fields */ }Expand description
Represents the contents of a pgpass file, see https://www.postgresql.org/docs/current/libpq-pgpass.html
Implementations
sourceimpl PgPassFile
impl PgPassFile
sourcepub fn find_password(
&self,
host: &str,
port: u16,
database: &str,
user: &str
) -> Option<&str>
pub fn find_password( &self, host: &str, port: u16, database: &str, user: &str ) -> Option<&str>
Find the password for a given host, port, database and user
Will always return the password for the first matching pgpass line, if there are overlapping rules, only the first password will be returned